repo stringclasses 15
values | fix_commit stringlengths 40 40 | buggy_commit stringlengths 40 40 | message stringlengths 3 64.3k | files listlengths 1 300 | timestamp timestamp[s]date 2013-03-13 20:45:00 2026-04-11 07:48:46 |
|---|---|---|---|---|---|
ggml-org/llama.cpp | 8da3c0e200a586f768ada6f38745acb01380174c | c22473b580807929fd9e3a3344a48e8cfbe6c88f | batch : fix consistency checks for the input positions (#16890) | [
{
"path": "src/llama-batch.cpp",
"patch": "@@ -261,15 +261,29 @@ bool llama_batch_allocr::init(\n \n const llama_pos p0 = memory ? memory->seq_pos_max(s) : -1;\n \n- if (p0 >= 0 && p0 >= seq_pos_min(s)) {\n- LLAMA_LOG_ERROR(\n- \"%s: the tokens of... | 2025-10-31T11:50:33 |
ollama/ollama | 6bbd6e26fb81637de90779760bf744f4dc3ad8b2 | e6ad4813d3ae1ac229aed71c5e609f829f61a25d | fix temporary newline created and removed with spinner in `ollama run` | [
{
"path": "cmd/cmd.go",
"patch": "@@ -457,7 +457,7 @@ func generate(cmd *cobra.Command, model, prompt string, wordWrap bool, format st\n \t}\n \n \tp := progress.NewProgress(os.Stderr)\n-\tdefer p.Stop()\n+\tdefer p.StopAndClear()\n \n \tspinner := progress.NewSpinner(\"\")\n \tp.Add(\"\", spinner)\n@@ -492... | 2023-11-20T05:49:08 |
vuejs/vue | 9c3e96f7573a671f085dab8cbd3bdb21dc4a9612 | 7497723c6add3945f9a2141da20e4a26945a628d | fix typo in comment (#5411) | [
{
"path": "src/platforms/web/runtime/directives/model.js",
"patch": "@@ -32,7 +32,7 @@ export default {\n el._vModifiers = binding.modifiers\n if (!binding.modifiers.lazy) {\n // Safari < 10.2 & UIWebView doesn't fire compositionend when\n- // siwtching focus before confirming com... | 2017-04-10T20:52:02 |
huggingface/transformers | 4d0b6758b90aa54e4077171e6d42c55e0c01c622 | 2f9e3ae7f532f12ff16648fd956687354847e151 | Fix: avoid duplicate token in maybe_load_adapters (#41903) | [
{
"path": "src/transformers/integrations/peft.py",
"patch": "@@ -651,13 +651,15 @@ def maybe_load_adapters(\n \n _adapter_model_path = adapter_kwargs.pop(\"_adapter_model_path\", None)\n \n+ token_from_adapter_kwargs = adapter_kwargs.pop(\"token\", None)\n+\n if _adapter_model_path is None:\n ... | 2025-10-28T15:07:23 |
ggml-org/llama.cpp | 0f715b4e759acceccb9f437cfd2a988fff85514a | d2d931f173b8a736b08999436e9259aafddec718 | server : fix typos in server.cpp comments [no ci] (#16883) | [
{
"path": "tools/server/server.cpp",
"patch": "@@ -3608,7 +3608,7 @@ struct server_context {\n slot.task->params.sampling.preserved_tokens.find(token) != slot.task->params.sampling.preserved_tokens.end();\n };\n \n- // frist, add sampled tokens from any ongoing sequences\n+ ... | 2025-10-31T08:51:26 |
ollama/ollama | e6ad4813d3ae1ac229aed71c5e609f829f61a25d | 13ba6df5abba724fdd06b5671c1707d4098592b2 | dont crash when redirecting stderr | [
{
"path": "progress/bar.go",
"patch": "@@ -37,7 +37,7 @@ func NewBar(message string, maxValue, initialValue int64) *Bar {\n func (b *Bar) String() string {\n \ttermWidth, _, err := term.GetSize(int(os.Stderr.Fd()))\n \tif err != nil {\n-\t\tpanic(err)\n+\t\ttermWidth = 80\n \t}\n \n \tvar pre, mid, suf stri... | 2023-11-20T04:50:45 |
denoland/deno | 0d86c74f9cbec8262f3a6b9dafad8736fa7eb9e6 | b42e616c87840dd51d4433d0b338a78eec82a42b | fix(compile): remove data.is_empty() check (#32125)
This check is not needed | [
{
"path": "cli/standalone/binary.rs",
"patch": "@@ -185,7 +185,6 @@ pub fn is_standalone_binary(exe_path: &Path) -> bool {\n libsui::utils::is_elf(&data)\n || libsui::utils::is_pe(&data)\n || libsui::utils::is_macho(&data)\n- || data.is_empty()\n }\n \n pub struct WriteBinOptions<'a> {",
"a... | 2026-02-12T10:45:22 |
vuejs/vue | 7497723c6add3945f9a2141da20e4a26945a628d | 682141fccc9b3224c3432afcd5befd23fba9b1a1 | disable duplicate attr warning in Edge (fix #5394) | [
{
"path": "src/compiler/parser/index.js",
"patch": "@@ -5,8 +5,8 @@ import { parseHTML } from './html-parser'\n import { parseText } from './text-parser'\n import { parseFilters } from './filter-parser'\n import { cached, no, camelize } from 'shared/util'\n-import { isIE, isServerRendering } from 'core/util... | 2017-04-10T12:51:50 |
huggingface/transformers | 8472ac683604fca316fa1e5bb10c82064dac7d1b | bf9171563725c263e9463a70e4e970f29a3eb49e | Fix installation cmds in docs (#41887)
* doc fixes
* Fix decorator
* up
* Revert changes | [
{
"path": "AGENTS.md",
"patch": "@@ -14,7 +14,7 @@ This AGENTS.md file provides guidance for code agents working with this codebase\n \n - PRs should be as brief as possible. Bugfix PRs in particular can often be only one or two lines long, and do not need large comments, docstrings or new functions in this... | 2025-10-27T11:08:05 |
ggml-org/llama.cpp | 2976b0374d36609b0429dd6ce48807e2ad39a7c2 | d2a2673dd1c86a01ab010e18b13b8bb959968c48 | vulkan: Fix crash when FP16 mul_mat accumulation is not supported (#16796)
* Experimenting crash fix
* added assert for aborting and fixed comment
* changed to check if a pipeline is empty or not
* Moved function in class definition
* replaced with is_empty
* Modified is_empty to check only unaligned pipelines | [
{
"path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp",
"patch": "@@ -145,8 +145,13 @@ static void ggml_vk_destroy_pipeline(vk::Device& device, vk_pipeline& pipeline);\n struct vk_matmul_pipeline_struct {\n vk_pipeline l, m, s;\n vk_pipeline a_l, a_m, a_s;\n+ // Returns true when all unaligned pipeline... | 2025-10-31T07:18:59 |
ollama/ollama | f6b317e8c9556b1865dd87f509acdc80097e5198 | ac5076ce1ed64c62d2d40701d9dd53d45fa4a1aa | fix sending too little data in chunk upload body | [
{
"path": "server/upload.go",
"patch": "@@ -123,19 +123,6 @@ func (b *blobUpload) Run(ctx context.Context, opts *RegistryOptions) {\n \tdefer blobUploadManager.Delete(b.Digest)\n \tctx, b.CancelFunc = context.WithCancel(ctx)\n \n-\tp, err := GetBlobsPath(b.Digest)\n-\tif err != nil {\n-\t\tb.err = err\n-\t\... | 2023-11-19T01:36:34 |
denoland/deno | 1b2a9f1615f227d354b49e391cae590f3267b500 | 53b9903d811a9451cf225e5444fe1c8308c9b432 | fix(ext/node): fix worker exit code propagation in `worker_threads` (#32124)
## Summary
- Properly propagate `process.exitCode` from Node `worker_threads` to
the parent, matching Node.js behavior. Previously exit codes were
hardcoded to 0 (natural exit) or 1 (error exit), ignoring
`process.exitCode` set by the worker.... | [
{
"path": "ext/node/polyfills/process.ts",
"patch": "@@ -696,6 +696,17 @@ process.reallyExit = (code: number) => {\n \n process._exiting = _exiting;\n \n+// deno-lint-ignore no-explicit-any\n+process._fatalException = function (err: any, fromPromise?: boolean) {\n+ const origin = fromPromise ? \"unhandledR... | 2026-02-12T09:38:40 |
vuejs/vue | 4b6913cb46be2f8f932f19adb63bbc6f388a3b76 | 4dff99d6e3b8cdfb7552e284b1aac5742449c531 | handle errors in nextTick (close #5277) | [
{
"path": "src/core/util/env.js",
"patch": "@@ -2,6 +2,7 @@\n /* globals MutationObserver */\n \n import { noop } from 'shared/util'\n+import { handleError } from './error'\n \n // can we use __proto__?\n export const hasProto = '__proto__' in {}\n@@ -123,15 +124,22 @@ export const nextTick = (function () {... | 2017-04-10T07:01:32 |
huggingface/transformers | bf9171563725c263e9463a70e4e970f29a3eb49e | 77e8b9f8dfc8e736ad2f603a5b2ae2b1076ed271 | Fix torch.no_grad decorator in VLMS (#41888)
Fix decorator | [
{
"path": "src/transformers/models/emu3/modeling_emu3.py",
"patch": "@@ -1392,7 +1392,7 @@ def get_image_features(self, pixel_values: torch.FloatTensor, image_sizes: torch\n image_features = torch.split(image_features, split_sizes)\n return image_features\n \n- @torch.no_grad\n+ @torch... | 2025-10-27T11:07:15 |
ggml-org/llama.cpp | d2a2673dd1c86a01ab010e18b13b8bb959968c48 | 13002a08960e51a76c4d696165b5d7638d2f2b99 | vulkan: fix shmem overrun in mmq id shader (#16873)
* vulkan: fix shmem overrun in mmq id shader
* metal : fix mul_mm_id
---------
Co-authored-by: Georgi Gerganov <ggerganov@gmail.com> | [
{
"path": "ggml/src/ggml-metal/ggml-metal-device.cpp",
"patch": "@@ -677,7 +677,7 @@ ggml_metal_pipeline_t ggml_metal_library_get_pipeline_mul_mm_id_map0(ggml_metal_\n char name[256];\n \n snprintf(base, 256, \"kernel_mul_mm_id_map0_ne20_%d\", ne20);\n- snprintf(name, 256, \"%s\", base);\n+ sn... | 2025-10-31T07:14:49 |
ollama/ollama | 258addc79911e3035cc77e17709f5264f359b6ba | c06b9b7304a53ed5526dc51fc4fcafc45d92be54 | fix comment in `progress.go` | [
{
"path": "progress/progress.go",
"patch": "@@ -51,7 +51,7 @@ func (p *Progress) StopAndClear() bool {\n \n \tstopped := p.Stop()\n \tif stopped {\n-\t\t// clear the progress bar by:\n+\t\t// clear all progress lines\n \t\tfor i := 0; i < p.pos; i++ {\n \t\t\tfmt.Fprint(p.w, \"\\033[A\\033[2K\\033[1G\")\n \... | 2023-11-19T18:46:19 |
denoland/deno | 53b9903d811a9451cf225e5444fe1c8308c9b432 | 7b43bca73e176f5ff6bbc7e8760eca296d5bf55f | fix(ext/web): recheck state after signaling abort on writable stream (#32129)
See the note under
[WritableStreamAbort](https://streams.spec.whatwg.org/#writable-stream-abort). | [
{
"path": "ext/web/06_streams.js",
"patch": "@@ -4308,11 +4308,12 @@ function transformStreamUnblockWrite(stream) {\n * @returns {Promise<void>}\n */\n function writableStreamAbort(stream, reason) {\n- const state = stream[_state];\n+ let state = stream[_state];\n if (state === \"closed\" || state ===... | 2026-02-12T09:13:09 |
vuejs/vue | 98326ce878247544914882b581e2cc560c3fe806 | b997af0c012d00b98c84c062326beb650b239e35 | add extra change listener for v-model (fix #5248, #5387) | [
{
"path": "src/platforms/web/runtime/directives/model.js",
"patch": "@@ -31,6 +31,11 @@ export default {\n } else if (vnode.tag === 'textarea' || el.type === 'text' || el.type === 'password') {\n el._vModifiers = binding.modifiers\n if (!binding.modifiers.lazy) {\n+ // Safari < 10.2 &... | 2017-04-10T05:57:18 |
huggingface/transformers | 7a833d1ccd41673030c85107f65f454c0c3222f5 | 8bde822a868bcc9fb156f8bd9b3e2b1aefffc480 | :rotating_light: [`Clip`] Fix masking and enable flash attention on all model types (#41750)
* fix
* make kwargs fully passed and adjust with outputs xxx
* propogate metaclip 2
* propogate mlcd and fix test
* style
* fix repo consistency, need to add ignore rules as those are building blocks
* style
* oops
* f... | [
{
"path": "src/transformers/models/clip/modeling_clip.py",
"patch": "@@ -22,7 +22,7 @@\n from torch import nn\n \n from ...activations import ACT2FN\n-from ...modeling_attn_mask_utils import _create_4d_causal_attention_mask, _prepare_4d_attention_mask\n+from ...masking_utils import create_causal_mask\n from... | 2025-10-24T18:44:10 |
ggml-org/llama.cpp | 9984cbb61d12491d604484fb38b678fa15064061 | ce18efeaf1234bd08f25bc08f88ef95cf5d9e51f | opencl: fix boundary handling for mul_mm (#16875) | [
{
"path": "ggml/src/ggml-opencl/kernels/mul_mm_f16_f32_l4_lm.cl",
"patch": "@@ -79,8 +79,8 @@ kernel void kernel_mul_mm_f16_f32_l4_lm(\n \n for (int block = 0; block < ne00; block += BK) {\n for (int l = 0; l < BM; l += loadstride_a) {\n- if (loadc_a + l < ne01) {\n- const ... | 2025-10-30T23:00:20 |
ollama/ollama | 02524a56ff167f6307454abdd3c63d090fdef392 | 1657c6abc7f2061debb285797ecf8d1d52c0ddce | check retry for authorization error | [
{
"path": "server/images.go",
"patch": "@@ -1131,6 +1131,7 @@ func makeRequestWithRetry(ctx context.Context, method string, requestURL *url.UR\n \t\tif !errors.Is(err, context.Canceled) {\n \t\t\tlog.Printf(\"request failed: %v\", err)\n \t\t}\n+\n \t\treturn nil, err\n \t}\n \n@@ -1150,7 +1151,13 @@ func m... | 2023-11-19T05:19:53 |
vuejs/vue | b997af0c012d00b98c84c062326beb650b239e35 | a150317324fec0968edd66dc434eaff7a4bc065a | Use genAssignmentCode in chehckbox model web compiler (#5402)
Fix #5398 | [
{
"path": "src/platforms/web/compiler/directives/model.js",
"patch": "@@ -91,7 +91,7 @@ function genCheckboxModel (\n '$$i=_i($$a,$$v);' +\n `if($$c){$$i<0&&(${value}=$$a.concat($$v))}` +\n `else{$$i>-1&&(${value}=$$a.slice(0,$$i).concat($$a.slice($$i+1)))}` +\n- `}else{${value}=$$c... | 2017-04-10T04:24:08 |
denoland/deno | 7b43bca73e176f5ff6bbc7e8760eca296d5bf55f | 82b506dbccc0be9f352da65796a9e2774b0d3b5f | fix(deploy): bypass minimumDependencyAge (#32136)
Closes #32135 | [
{
"path": "cli/tools/deploy.rs",
"patch": "@@ -2,6 +2,7 @@\n \n use std::sync::Arc;\n \n+use deno_config::deno_json::NewestDependencyDate;\n use deno_config::deno_json::NodeModulesDirMode;\n use deno_core::error::AnyError;\n use deno_core::url::Url;\n@@ -22,6 +23,7 @@ pub async fn deploy(\n ) -> Result<i32,... | 2026-02-12T02:31:17 |
huggingface/transformers | 8bde822a868bcc9fb156f8bd9b3e2b1aefffc480 | 9bb51b311fd7d190a7a8b6fbe58be43c3e0c20ea | Fix TypeError: find_adapter_config_file() got an unexpected keyword argument '_adapter_model_path' (#41604)
* Pass original dict instead of copy to maybe_load_adapters
* Revert "Pass original dict instead of copy to maybe_load_adapters"
This reverts commit 26fe1b3f35419fdc14932dfbda6bb39e4bdb9b34.
* Return cleaned ... | [
{
"path": "src/transformers/integrations/peft.py",
"patch": "@@ -628,7 +628,7 @@ def maybe_load_adapters(\n **adapter_kwargs,\n ):\n if pretrained_model_name_or_path is None or not is_peft_available():\n- return None, pretrained_model_name_or_path\n+ return None, pretrained_model_name_... | 2025-10-24T17:52:14 |
ggml-org/llama.cpp | b52edd25586fabb70f0c21b274473b307cf14499 | 517b7170e1a4d733583c4b07c5b7a49acc05911c | server : remove n_past (#16818)
* server : remove n_past
* server : replace slot.n_prompt_tokens() with slot.task->n_tokens()
* server : fixes + clean-up
* cont : fix context shift
* server : add server_tokens::pos_next()
Co-authored-by: Xuan-Son Nguyen <son@huggingface.co>
* server : fix pos_next() usage
Co-au... | [
{
"path": "tools/server/README.md",
"patch": "@@ -587,7 +587,7 @@ These words will not be included in the completion, so make sure to add them to\n - `word`: Stopped due to encountering a stopping word from `stop` JSON array provided\n - `stopping_word`: The stopping word encountered which stopped the gen... | 2025-10-30T16:42:57 |
ollama/ollama | 43a726149df828e1557608bdffa97efc806ee448 | 984714f13182a6b32a8d456427536bbe51d6032e | fix potentially inaccurate error message | [
{
"path": "llm/llama.go",
"patch": "@@ -226,7 +226,7 @@ type llama struct {\n }\n \n var (\n-\terrNvidiaSMI = errors.New(\"nvidia-smi command failed\")\n+\terrNvidiaSMI = errors.New(\"warning: gpu support may not be enabled, check you have installed GPU drivers: nvidia-smi command failed\")\n \terrA... | 2023-11-17T23:05:28 |
vuejs/vue | c82546c54b851cb75d1fe17bd9d35038904efa24 | 561bb467baa49606e011a8d1e675b385b156763a | fix keep-alive pruning active instance | [
{
"path": "src/core/components/keep-alive.js",
"patch": "@@ -1,6 +1,5 @@\n /* @flow */\n \n-import { callHook } from 'core/instance/lifecycle'\n import { getFirstComponentChild } from 'core/vdom/helpers/index'\n \n type VNodeCache = { [key: string]: ?VNode };\n@@ -21,13 +20,15 @@ function matches (pattern: ... | 2017-04-07T08:11:40 |
denoland/deno | 82b506dbccc0be9f352da65796a9e2774b0d3b5f | 8cabe269e9335ddec286ad59504936ad769422fc | fix(node/ext): make zlib write callback async to match node behavior (#32130)
Deno's zlib `Zlib::write` was calling `processCallback` synchronously,
while Node.js runs compression on the libuv threadpool and calls it
asynchronously. This caused several issues:
- destroy() couldn't propagate before subsequent write ca... | [
{
"path": "ext/node/ops/zlib/mod.rs",
"patch": "@@ -473,7 +473,7 @@ impl Zlib {\n #[smi] out_off: u32,\n #[smi] out_len: u32,\n ) -> Result<(), ZlibError> {\n- let (err_info, callback) = {\n+ let err_info = {\n let mut zlib = self.inner.borrow_mut();\n let zlib = zlib.as_mut().ok... | 2026-02-12T01:02:19 |
huggingface/transformers | 9bb51b311fd7d190a7a8b6fbe58be43c3e0c20ea | 090a8946c6568c0e9440b09bc0c0c608e3a92986 | Share embedding modules in BART, not only weights (#41821)
* Share embedding modules in BART, not only weights
Embedding modules are now shared between encoder, decoder
and shared - it is the same module, like in the T5 implementation.
This has the benefit that it does not matter which module is returned
in `get_inp... | [
{
"path": "src/transformers/models/bart/modeling_bart.py",
"patch": "@@ -538,12 +538,12 @@ def __init__(self, config: BartConfig, embed_tokens: Optional[nn.Embedding] = No\n self.max_source_positions = config.max_position_embeddings\n embed_scale = math.sqrt(embed_dim) if config.scale_embedd... | 2025-10-24T15:22:02 |
ggml-org/llama.cpp | 835e918d8428f5119927d7150bf5a26176dedda0 | d261223d24e97f2df50220e4a5b7f0adb69bba81 | common: fix typo in cli help text (#16864) | [
{
"path": "common/arg.cpp",
"patch": "@@ -3203,7 +3203,7 @@ common_params_context common_params_parser_init(common_params & params, llama_ex\n ).set_examples({LLAMA_EXAMPLE_IMATRIX}));\n add_opt(common_arg(\n {\"--parse-special\"},\n- string_format(\"prase special tokens (chat, tool, ... | 2025-10-30T15:47:31 |
vuejs/vue | 1073035164b809872bf35a3b007848979f86f48a | 931aaea8dc6481f59b3f9dcf7b304bb36e6e27ad | fix activate hook call timing (fix vue-router#1212) | [
{
"path": "flow/vnode.js",
"patch": "@@ -9,6 +9,7 @@ declare type VNodeComponentOptions = {\n }\n \n declare type MountedComponentVNode = {\n+ context: Component;\n componentOptions: VNodeComponentOptions;\n componentInstance: Component;\n parent: VNode;",
"additions": 1,
"deletions": 0,
... | 2017-04-07T07:30:37 |
huggingface/transformers | 090a8946c6568c0e9440b09bc0c0c608e3a92986 | 4faf675232d01b99329aa8dfb32ab1aa2fba980b | Fix const parsing for dict inputs in chat schemas (#41824)
* Fix const parsing for dict inputs
* make fixup | [
{
"path": "src/transformers/utils/chat_parsing_utils.py",
"patch": "@@ -173,12 +173,12 @@ def recursive_parse(\n return parsed_schema\n elif isinstance(node_content, dict):\n for key, child_node in node_schema.get(\"properties\", {}).items():\n- if key in node_... | 2025-10-24T14:14:06 |
denoland/deno | 133d02e064a8e07cabab226d815d0b3ba684fc88 | c6ed5f01c5b0361fd582a4b19f97aa5f2effad36 | fix(node): unconditionally call `Module.prototype._compile` with the file content in `loadMaybeCjs` (#32131) | [
{
"path": "ext/node/polyfills/01_require.js",
"patch": "@@ -1080,9 +1080,8 @@ Module._extensions[\".mjs\"] = loadESMFromCJS;\n Module._extensions[\".wasm\"] = loadESMFromCJS;\n \n function loadMaybeCjs(module, filename) {\n- const isMaybeCjs = op_require_is_maybe_cjs(filename);\n- const format = isMaybeCj... | 2026-02-11T21:08:15 |
vuejs/vue | ba138549dbba95ea019f0626fe185360723ddda2 | c28b566f19459751244707e4efe458056c9bbdcf | fix style (#5383) | [
{
"path": "benchmarks/big-table/demo.css",
"patch": "@@ -1,5 +1,5 @@\n form {\n- margin-bottom: 15px ;\n+ margin-bottom: 15px;\n }\n \n td.hidden {",
"additions": 1,
"deletions": 1,
"language": "CSS"
},
{
"path": "benchmarks/big-table/index.html",
"patch": "@@ -71,12 +71,12 @@ <h1>... | 2017-04-06T02:50:21 |
ggml-org/llama.cpp | d261223d24e97f2df50220e4a5b7f0adb69bba81 | dcca0d3ab840ebe9b2ccd4719033d408eeb758d7 | model: add support for qwen3vl series (#16780)
* support qwen3vl series.
Co-authored-by: Thireus ☠ <Thireus@users.noreply.github.com>
Co-authored-by: yairpatch <yairpatch@users.noreply.github.com>
Co-authored-by: LETS-BEE <LETS-BEE@users.noreply.github.com>
* bugfix: fix the arch check for qwen3vl-moe.
* use build_... | [
{
"path": "convert_hf_to_gguf.py",
"patch": "@@ -3852,7 +3852,43 @@ def set_gguf_parameters(self):\n def modify_tensors(self, data_torch: Tensor, name: str, bid: int | None) -> Iterable[tuple[str, Tensor]]:\n # process the experts separately\n name = name.replace(\"language_model.\", \"\... | 2025-10-30T15:19:14 |
ollama/ollama | c6e6c8ee7e86b774436a18e72bb3b5f1c495ae43 | a185b29719a5ed93d1a7b18ad9d0b489e2a312f0 | fix cross device rename | [
{
"path": "server/routes.go",
"patch": "@@ -666,8 +666,14 @@ func HeadBlobHandler(c *gin.Context) {\n }\n \n func CreateBlobHandler(c *gin.Context) {\n+\ttargetPath, err := GetBlobsPath(c.Param(\"digest\"))\n+\tif err != nil {\n+\t\tc.AbortWithStatusJSON(http.StatusInternalServerError, gin.H{\"error\": err.... | 2023-11-17T23:21:57 |
huggingface/transformers | 4faf675232d01b99329aa8dfb32ab1aa2fba980b | bb6028cb7938e33ec9e75a0b47b27a6b75584151 | Fix Qwen2Audio flash attention mask format for generation (#41843)
* Fix Qwen2Audio flash attention mask format for generation
* use create_bidirectional_mask instead
* fix
* fix
* empty
* fix | [
{
"path": "src/transformers/models/qwen2_audio/modeling_qwen2_audio.py",
"patch": "@@ -25,6 +25,7 @@\n from ...activations import ACT2FN\n from ...cache_utils import Cache\n from ...generation import GenerationMixin\n+from ...masking_utils import create_bidirectional_mask\n from ...modeling_layers import Gr... | 2025-10-24T12:45:48 |
vuejs/vue | 7d3c883f83332c13ca186f7e7ee5be40e47f85a7 | 4e12b25d785aa721d71ec2f553d150c8df15f875 | fix functional context resolving merge errors | [
{
"path": "src/core/instance/inject.js",
"patch": "@@ -51,19 +51,7 @@ export function resolveInject (inject: any, vm: Component): ?Object {\n let source = vm\n while (source) {\n if (source._provided && provideKey in source._provided) {\n- /* istanbul ignore else */\n- ... | 2017-04-05T07:55:44 |
denoland/deno | 512d9196c5056933ff032a3c52efb4e8fae95d0d | 652d4d2055e7ef2e9c41c9346051db5101aa01bc | fix(install): cleanup `node_modules` folder on install (#32058)
This is only for `deno install/add/remove`. We don't do this for other
commands because it could cause problems (ex. two deno subprocesses
running at the same time with "lazy npm deps" or whatever it's called)
and also it would add more startup time. | [
{
"path": "Cargo.lock",
"patch": "@@ -9528,9 +9528,9 @@ dependencies = [\n \n [[package]]\n name = \"sys_traits\"\n-version = \"0.1.22\"\n+version = \"0.1.24\"\n source = \"registry+https://github.com/rust-lang/crates.io-index\"\n-checksum = \"4121e69c72108134f9daf82cf6580269f018f5d8fb8cd3063df17699fbb84cb1... | 2026-02-11T20:08:25 |
ollama/ollama | a185b29719a5ed93d1a7b18ad9d0b489e2a312f0 | dc84b20d6be6f78b524d8eb5588011105b5c7eb3 | fix install script error on linux | [
{
"path": "scripts/install.sh",
"patch": "@@ -97,16 +97,6 @@ Environment=\"PATH=$PATH\"\n [Install]\n WantedBy=default.target\n EOF\n-\n- mkdir -p /etc/systemd/system/ollama.service.d\n- cat <<EOF | $SUDO tee /etc/systemd/system/ollama.service.d/environment.conf >/dev/null\n-[Service]\n-#Environment=\... | 2023-11-17T23:00:41 |
huggingface/transformers | bb6028cb7938e33ec9e75a0b47b27a6b75584151 | 7935b869dc93932b291c7962dccf07c13b47789f | Fix MXFP4 quantizer to support variable num_local_experts and hidden_size (#41795)
Fix MXFP4 quantizer to support variable num_local_experts | [
{
"path": "src/transformers/quantizers/quantizer_mxfp4.py",
"patch": "@@ -383,6 +383,10 @@ def get_state_dict_and_metadata(self, model, safe_serialization: bool = False):\n \n state_dict = model.state_dict()\n \n+ # Get num_local_experts from model config\n+ num_local_experts = getattr... | 2025-10-24T12:18:52 |
ggml-org/llama.cpp | bacddc049a00786df44e682262f6e298742bfbc3 | 229bf686287d18f82c44e89888cc662145ecfdb4 | model: Add support for CogVLM model (#15002)
* Added GGUF mappings for CogVLM model
* Add tensor mapping for CogVLM visual encoder
* Add CogVLM to conversion script, no vision part yet
* Added CogVLM vision model to conversion script
* Add graph for CogVLM CLIP model
* Add graph for CogVLM
* Fixes for CogVLM. No... | [
{
"path": "convert_hf_to_gguf.py",
"patch": "@@ -1528,7 +1528,7 @@ def set_gguf_parameters(self):\n self.gguf_writer.add_vision_embedding_length(self.find_vparam([\"hidden_size\"]))\n self.gguf_writer.add_vision_feed_forward_length(self.find_vparam([\"intermediate_size\"]))\n ... | 2025-10-30T11:18:50 |
vuejs/vue | beee7d81430ea6e81c508d63994065c9341d0cf2 | 354c2f4922fe34932d4866da39cb8e0ac87e9edd | support v-on passive modifier (#5132)
* support v-on passive modifier
* fix supportsPassive and run unit when the test browser supports
* add mutual exclusive warning
* Fix typo
* Fix typo
* Remove extra line - CS fix | [
{
"path": "src/compiler/helpers.js",
"patch": "@@ -1,5 +1,6 @@\n /* @flow */\n \n+import { warn } from 'core/util/index'\n import { parseFilters } from './parser/filter-parser'\n \n export function baseWarn (msg: string) {\n@@ -41,6 +42,13 @@ export function addHandler (\n modifiers: ?ASTModifiers,\n im... | 2017-04-05T06:35:16 |
denoland/deno | 652d4d2055e7ef2e9c41c9346051db5101aa01bc | d09571c95ed9e56fb870abc82bb876cbadf02ea3 | fix(ext/web): prevent GC of AbortSignal.any() (#32118)
The new exposed `AbortSignal.any()`, stores dependent signals via
`WeakRef` in the source signal's `dependentSignals` set. When the
dependent signal is created as a temporary (e.g.
`AbortSignal.any([...]).addEventListener("abort", cb)`), there are no
strong refere... | [
{
"path": "ext/web/03_abort_signal.js",
"patch": "@@ -79,6 +79,7 @@ const sourceSignals = Symbol(\"[[sourceSignals]]\");\n const dependentSignals = Symbol(\"[[dependentSignals]]\");\n const signal = Symbol(\"[[signal]]\");\n const timerId = Symbol(\"[[timerId]]\");\n+const activeDependents = Symbol(\"[[acti... | 2026-02-11T15:17:41 |
huggingface/transformers | c27efe6e65fb2dfe5cbbe00694908f471b06c8ae | 8c291846f58fc9a4a51f50491e020eb5c27d9614 | further reducing flakiness in `utils/check_bad_commit.py` (#41658) (#41815)
* 111
* fix
* fix
* fix
---------
Co-authored-by: ydshieh <ydshieh@users.noreply.github.com> | [
{
"path": "utils/check_bad_commit.py",
"patch": "@@ -97,7 +97,17 @@ def is_bad_commit(target_test, commit):\n # Restore to original commit\n repo.git.checkout(original_head)\n \n- return result.returncode != 0\n+ n_passed = 0\n+ o = re.findall(r\"====.* (\\d+) passed\", result.stdout)\n+ ... | 2025-10-24T09:36:01 |
ggml-org/llama.cpp | 229bf686287d18f82c44e89888cc662145ecfdb4 | d7395115baf395b75a73a17b0b796e746e468da9 | cuda : fix argsort with 64k+ rows (#16849) | [
{
"path": "ggml/src/ggml-cuda/argsort.cu",
"patch": "@@ -87,7 +87,7 @@ template<ggml_sort_order order>\n static __global__ void k_argsort_f32_i32(const float * x, int * dst, const int ncols, int ncols_pad) {\n // bitonic sort\n int col = threadIdx.x;\n- int row = blockIdx.y;\n+ int row = block... | 2025-10-30T07:56:28 |
vuejs/vue | 354c2f4922fe34932d4866da39cb8e0ac87e9edd | bbec0763ab6eb8824c8bfb447844bfa2892ee47a | fix keep-alive cache incorrectly pruned with transition mode="out-in" (fix #5346) | [
{
"path": "src/platforms/web/runtime/components/transition.js",
"patch": "@@ -53,9 +53,11 @@ export function extractTransitionData (comp: Component): Object {\n }\n \n function placeholder (h: Function, rawChild: VNode): ?VNode {\n- return /\\d-keep-alive$/.test(rawChild.tag)\n- ? h('keep-alive')\n- ... | 2017-04-03T07:32:23 |
denoland/deno | d09571c95ed9e56fb870abc82bb876cbadf02ea3 | 77c1c1920fb5236dc98748b56a55e7f3ce622a86 | fix(ext/napi): don't mark accessor properties as read-only in napi_define_class (#32105)
## Summary
- In `napi_define_class`, accessor properties (getter/setter) were
incorrectly marked `READ_ONLY` when `napi_writable` was not set in the
property attributes. Per the Node-API spec, `napi_writable` only applies
to data... | [
{
"path": "ext/napi/js_native_api.rs",
"patch": "@@ -285,13 +285,6 @@ fn napi_define_class<'s>(\n let setter = p\n .setter\n .map(|s| create_function_template(scope, env_ptr, None, s, p.data));\n- if getter.is_some()\n- && setter.is_some()\n- && (p.attributes & napi_... | 2026-02-11T07:38:42 |
ollama/ollama | c82ead4d01411ac5b6b863e782faae066c00f2ad | 90860b6a7e1cd8ce6a200ff39f9779041d3726e3 | faq: fix heading and add more details | [
{
"path": "docs/faq.md",
"patch": "@@ -149,8 +149,8 @@ docker build -t ollama-with-ca .\n docker run -d -e HTTPS_PROXY=https://my.proxy.example.com -p 11434:11434 ollama-with-ca\n ```\n \n-### How do I use Ollama with GPU acceleration in Docker?\n+## How do I use Ollama with GPU acceleration in Docker?\n \n... | 2023-11-17T17:00:14 |
huggingface/transformers | 8c291846f58fc9a4a51f50491e020eb5c27d9614 | beb71b757584b0f9ef3c493fa9de49dc54c33b1d | extend 2 blip2 and falcon_h1 test cases to xpu (#41825)
* extend 2 blip2 and falcon_h1 test cases to xpu
Signed-off-by: Yao, Matrix <matrix.yao@intel.com>
* fix style
Signed-off-by: Yao, Matrix <matrix.yao@intel.com>
* xx
Signed-off-by: Yao, Matrix <matrix.yao@intel.com>
---------
Signed-off-by: Yao, Matrix <ma... | [
{
"path": "tests/models/blip_2/test_modeling_blip_2.py",
"patch": "@@ -28,7 +28,6 @@\n require_torch,\n require_torch_accelerator,\n require_torch_fp16,\n- require_torch_gpu,\n require_torch_multi_accelerator,\n require_vision,\n slow,\n@@ -1734,7 +1733,7 @@ def test_inference_t5_... | 2025-10-24T09:15:15 |
ggml-org/llama.cpp | 3464bdac37027c5e9661621fc75ffcef3c19c6ef | e3af5563bd049141e036b50f843196db33d23e97 | llama: fix ASAN error with M-RoPE (#16848) | [
{
"path": "src/llama-batch.cpp",
"patch": "@@ -669,10 +669,8 @@ llama_ubatch llama_batch_allocr::ubatch_add(const std::vector<int32_t> & idxs, u\n \n auto udata = std::make_shared<llama_ubatch::data_t>();\n \n- const int32_t n_pos_cur = batch.embd ? n_pos_per_embd : 1;\n-\n const int64_t n_embd_a... | 2025-10-29T19:11:39 |
denoland/deno | 77c1c1920fb5236dc98748b56a55e7f3ce622a86 | 1f36bf720d0458285b6893339c9cbd300104e4cf | fix(ext/node): fix `test-worker-process-argv.js` test (#32074)
Done with @claude | [
{
"path": "ext/node/polyfills/worker_threads.ts",
"patch": "@@ -44,9 +44,11 @@ import {\n } from \"ext:deno_web/01_broadcast_channel.js\";\n import { untransferableSymbol } from \"ext:deno_node/internal_binding/util.ts\";\n import process from \"node:process\";\n+import { fileURLToPath } from \"node:url\";\... | 2026-02-11T07:27:51 |
vuejs/vue | a12d32a56df2519c9cdf8d2da9d9425876263f89 | 66228390684eb23dc943dfe30d4ccd0063f797ef | fix style diffing on cached/slot elements (fix #5318) | [
{
"path": "flow/vnode.js",
"patch": "@@ -40,6 +40,7 @@ declare interface VNodeData {\n class?: any;\n staticStyle?: { [key: string]: any };\n style?: Array<Object> | Object;\n+ normalizedStyle?: Object;\n props?: { [key: string]: any };\n attrs?: { [key: string]: string };\n domProps?: { [key: ... | 2017-04-03T06:13:57 |
huggingface/transformers | 81b4f9882c8a46c8274084503d297874bb372260 | 2a3f66d9d28b070b5f52495dbeda010a2f5e3613 | transformers serve quantization docs + some api fixes for bitsandbytes (#41253)
* doc
* fix api
* fix
* fix
* fix
* fix args
* minor doc fix
* fix
* style
* rm check for now
* fix
* style
* Update docs/source/en/serving.md
Co-authored-by: Mohamed Mekkouri <93391238+MekkCyber@users.noreply.github.com>
* a... | [
{
"path": "docs/source/en/serving.md",
"patch": "@@ -383,6 +383,30 @@ transformers serve \\\n --attn_implementation \"sdpa\"\n ```\n \n+### Quantization\n+\n+transformers serve is compatible with all [quantization methods](https://huggingface.co/docs/transformers/main/quantization/overview) supported in t... | 2025-10-23T16:00:54 |
ggml-org/llama.cpp | e3af5563bd049141e036b50f843196db33d23e97 | 10fcc41290e233788f5a4215314156e8e023eb92 | llama: store mrope data in KV cell (#16825)
* llama: store mrope data in KV cell
* correct x,y ordering
* address review comments
* add consistency checks
* Update src/llama-kv-cache.cpp
Co-authored-by: Georgi Gerganov <ggerganov@gmail.com>
* add TODO
* fix asan error
* kv-cells : improve ext handling
* cont ... | [
{
"path": "src/llama-batch.cpp",
"patch": "@@ -215,6 +215,7 @@ bool llama_batch_allocr::init(\n /*.n_seq_tokens =*/ (uint32_t) 1,\n /*.n_seqs =*/ (uint32_t) batch.n_tokens,\n /*.n_seqs_unq =*/ (uint32_t) this->seq_id_unq.size(),\n+ /*.n_pos =*/ n... | 2025-10-29T17:09:18 |
denoland/deno | 61a034e3db89c648e337c7ebeabe095d2ff7dc8d | 163e95d7d809fcd0e806086e997f4049576cd865 | fix(repl): handle EOF gracefully in JSON REPL mode (#32108)
Closes the JSON REPL cleanly when the IPC pipe is closed (e.g. ctrl+d /
EOF) instead of printing `error: unexpected end of file` and exiting
with code 1. | [
{
"path": "cli/tools/repl/mod.rs",
"patch": "@@ -310,15 +310,25 @@ async fn run_json(mut repl_session: ReplSession) -> Result<i32, AnyError> {\n \n loop {\n let mut line_fut = std::pin::pin!(async {\n- let len = receiver.read_u32_le().await?;\n- let mut buf = vec![0; len as _];\n+ let l... | 2026-02-10T08:33:34 |
vuejs/vue | 3c0265517b55afe747948c193b79954d18b4d4c8 | 255b627f395c5e658862cf716291a6299f997cb7 | handle errors thrown by directive hooks (#5314) (#5324)
* handle errors thrown by directive hooks
* fix import | [
{
"path": "src/core/vdom/modules/directives.js",
"patch": "@@ -1,7 +1,7 @@\n /* @flow */\n \n import { emptyNode } from 'core/vdom/patch'\n-import { resolveAsset } from 'core/util/options'\n+import { resolveAsset, handleError } from 'core/util/index'\n import { mergeVNodeHook } from 'core/vdom/helpers/index... | 2017-04-03T03:37:54 |
huggingface/transformers | 2a3f66d9d28b070b5f52495dbeda010a2f5e3613 | ca01fe4d133a498a81bdfd335024d14801e106a2 | Deprecate warmup_ratio (#41326)
* dep
* style
* deprecate warmup_ratio
* better
* fix
* Revert "style"
This reverts commit cf4f9e7c4f7837a88eea6eeabf8b4dfe9455f6dc.
* Revert "dep"
This reverts commit 1800beb13f407ddb881d0af936860643e84ba085.
* update version | [
{
"path": "docs/source/en/optimizers.md",
"patch": "@@ -154,7 +154,7 @@ pip install schedulefree\n \n [Schedule Free optimizer (SFO)](https://hf.co/papers/2405.15682) replaces the base optimizers momentum with a combination of averaging and interpolation. Unlike a traditional scheduler, SFO completely remov... | 2025-10-23T15:17:21 |
ggml-org/llama.cpp | bcf5bda6f5df559565d11d7c8e8295c1159a85ec | 3eb2be1ca5f37480aeb16102970d9e65f43347fe | Vulkan MMQ Integer Dot Refactor and K-Quant support (#16536)
* vulkan: add mmq q2_k integer dot support
* Refactor mmq caching
* Reduce mmq register use
* Load 4 quant blocks into shared memory in one step
* Pack q2_k blocks into caches of 32
* Use 32-bit accumulators for integer dot matmul
* Add q4_k mmq
* Add... | [
{
"path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp",
"patch": "@@ -486,6 +486,7 @@ struct vk_device_struct {\n vk_matmul_pipeline2 pipeline_matmul_id_f16_f32;\n \n vk_matmul_pipeline2 pipeline_dequant_mul_mat_mat_id[GGML_TYPE_COUNT];\n+ vk_matmul_pipeline2 pipeline_dequant_mul_mat_mat_id_q8_1[GGML_T... | 2025-10-29T13:39:03 |
denoland/deno | 163e95d7d809fcd0e806086e997f4049576cd865 | f88d88fc5458f383fa8b36e73d43b58e2707a571 | fix(compile): use a temporary directory with a node_modules folder when compiling npm specifiers (#32084) | [
{
"path": "cli/main.rs",
"patch": "@@ -112,26 +112,28 @@ fn spawn_subcommand<F: Future<Output = T> + 'static, T: SubcommandOutput>(\n }\n \n async fn run_subcommand(\n- flags: Arc<Flags>,\n+ flags: Flags,\n unconfigured_runtime: Option<UnconfiguredRuntime>,\n roots: LibWorkerFactoryRoots,\n ) -> Resul... | 2026-02-09T16:50:00 |
vuejs/vue | 255b627f395c5e658862cf716291a6299f997cb7 | 9311876c7c0084a65c6ff0d583d2789205fa83ee | fix #5321 don't throw error when node gets relocated (#5322)
* don't throw error when node gets relocated
* perf: Simplify if check in vdom/patch | [
{
"path": "src/core/vdom/patch.js",
"patch": "@@ -234,7 +234,9 @@ export function createPatchFunction (backend) {\n function insert (parent, elm, ref) {\n if (isDef(parent)) {\n if (isDef(ref)) {\n- nodeOps.insertBefore(parent, elm, ref)\n+ if (ref.parentNode === parent) {\n+ ... | 2017-04-03T03:36:50 |
huggingface/transformers | ca01fe4d133a498a81bdfd335024d14801e106a2 | f780932e05bf3d240fc3c075fd9a07bf23ab30e4 | transformers cli default flag fix (#41761) | [
{
"path": "src/transformers/cli/run.py",
"patch": "@@ -51,7 +51,7 @@ def run(\n Optional[str],\n typer.Option(help=\"Name of the column to use as input. For multi columns input use 'column1,columns2'\"),\n ] = None,\n- format: Annotated[FormatEnum, typer.Option(help=\"Input format to ... | 2025-10-23T13:33:55 |
ollama/ollama | a5ccf742c1ab0af3f350a42a5a4e511780c238b3 | e33ef391cd937f1e46e7f257e7722e3014c79981 | fix cross repo mounts | [
{
"path": "server/upload.go",
"patch": "@@ -77,6 +77,14 @@ func (b *blobUpload) Prepare(ctx context.Context, requestURL *url.URL, opts *Reg\n \n \tb.Total = fi.Size()\n \n+\t// http.StatusCreated indicates a blob has been mounted\n+\t// ref: https://distribution.github.io/distribution/spec/api/#cross-reposi... | 2023-11-16T20:18:03 |
ggml-org/llama.cpp | 9a3ea685b937c0f0cbfda2e50004ea54bf187512 | 338074c383c81366320d176d83b94b0a567ee0c2 | CUDA: Fix bug in topk-moe for gpt-oss (#16821)
* CUDA: Fix bug in topk-moe for gpt-oss
When using ggml_can_fuse_subgraph, the output nodes which are passed are wrong. This causes `test-backend-ops` to still fuse ndoes (because the nodes are not used elsewhere in the graph),
but it actually doesn't fuse in the actual ... | [
{
"path": "ggml/src/ggml-cuda/ggml-cuda.cu",
"patch": "@@ -2978,7 +2978,7 @@ static bool ggml_cuda_can_fuse(const struct ggml_cgraph * cgraph, int node_idx,\n ggml_cuda_topk_moe_ops(/*with_norm=*/false, /*delayed_softmax=*/true);\n \n if (ops.size() == topk_moe_ops_with_norm.size() &&\n- ... | 2025-10-29T07:55:06 |
denoland/deno | f88d88fc5458f383fa8b36e73d43b58e2707a571 | 0a6b424b9ae713271afa1bf1b21fd1cfd3e55e59 | fix(ext/node): serialize workerData before resolving worker filename (#32091)
Fixes `parallel/test-worker-invalid-workerdata.js` | [
{
"path": "ext/node/polyfills/worker_threads.ts",
"patch": "@@ -169,27 +169,10 @@ class NodeWorker extends EventEmitter {\n \"node:worker_threads support only 'file:' and 'data:' URLs\",\n );\n }\n- if (options?.eval) {\n- const code = typeof specifier === \"string\"\n- ? en... | 2026-02-09T15:07:38 |
huggingface/transformers | f780932e05bf3d240fc3c075fd9a07bf23ab30e4 | e7c5a60368ba817640328a059c2b838f9e00a1dc | Fixed some grammar mistakes (#41802)
Added spaces between words, fixed a typo and other errors | [
{
"path": "docs/README.md",
"patch": "@@ -24,7 +24,7 @@ pip install -e \".[dev]\"\n ```\n \n > [!NOTE]\n-> This command might fail for some OS that are missing dependencies. Check step 4 in [Create a Pull Request](https://github.com/huggingface/transformers/blob/main/CONTRIBUTING.md#create-a-pull-request) t... | 2025-10-23T12:39:58 |
vuejs/vue | 9311876c7c0084a65c6ff0d583d2789205fa83ee | 71e0992127a8144c7b095af1e18376318fc77cb0 | safer isNative check (fix #5361) | [
{
"path": "src/core/util/env.js",
"patch": "@@ -37,8 +37,8 @@ export const isServerRendering = () => {\n export const devtools = inBrowser && window.__VUE_DEVTOOLS_GLOBAL_HOOK__\n \n /* istanbul ignore next */\n-export function isNative (Ctor: Function): boolean {\n- return /native code/.test(Ctor.toString... | 2017-04-03T03:33:49 |
ollama/ollama | e33ef391cd937f1e46e7f257e7722e3014c79981 | 75295b952899daaa1ad188088c5f37e62a414b55 | fix push scope error for inherited model | [
{
"path": "server/upload.go",
"patch": "@@ -55,7 +55,7 @@ func (b *blobUpload) Prepare(ctx context.Context, requestURL *url.URL, opts *Reg\n \tif b.From != \"\" {\n \t\tvalues := requestURL.Query()\n \t\tvalues.Add(\"mount\", b.Digest)\n-\t\tvalues.Add(\"from\", b.From)\n+\t\tvalues.Add(\"from\", ParseModel... | 2023-11-16T19:44:09 |
ggml-org/llama.cpp | 338074c383c81366320d176d83b94b0a567ee0c2 | 851553ea6b24cb39fd5fd188b437d777cb411de8 | sycl: add RMS_NORM_BACK operation support (#16808)
* sycl: add RMS_NORM_BACK operation support
* sycl: rms_norm_back: add dual reduction paths (FP64 and FP32) and savepoint before further changes
* sycl: add RMS_NORM_BACK support
Implement RMS_NORM_BACK for the SYCL backend using FP32 compensated parallel reduction... | [
{
"path": "docs/ops.md",
"patch": "@@ -79,7 +79,7 @@ Legend:\n | REPEAT | ❌ | ✅ | ✅ | 🟡 | ✅ | 🟡 | ✅ | 🟡 | ❌ |\n | REPEAT_BACK | ❌ | ❌ | ✅ | ✅ | ❌ | ❌ | ❌ | ✅ | ❌ |\n | RMS_NORM | ❌ | ✅ | ✅ | ✅ | 🟡 | ✅ | ✅ | ✅ | ❌ |\n-| ... | 2025-10-29T06:14:39 |
denoland/deno | 0a6b424b9ae713271afa1bf1b21fd1cfd3e55e59 | 131b706bcfadea4d50e6c87bed3fc165b9f02d84 | fix(ext/node): `fs.writeFile` and `FileHandle.writeFile` compatibility (#32077) | [
{
"path": "ext/node/polyfills/_fs/_fs_common.ts",
"patch": "@@ -1,18 +1,12 @@\n // Copyright 2018-2026 the Deno authors. MIT license.\n \n import { primordials } from \"ext:core/mod.js\";\n-const {\n- StringPrototypeToLowerCase,\n- ArrayPrototypeIncludes,\n- ReflectApply,\n- Error,\n-} = primordials;\n+... | 2026-02-09T14:49:03 |
vuejs/vue | 1e37633567f5d015db24ae0210b1adb4b1c3d355 | 924435a0fae3dfeb2616c9ac17bed99f9cb8d28d | fix ssr xss (fix #5351) | [
{
"path": "src/core/vdom/helpers/resolve-async-component.js",
"patch": "@@ -1,5 +1,12 @@\n /* @flow */\n \n+// () => ({\n+// component: import('./xxx.vue'),\n+// delay: 200,\n+// loading: LoadingComponent,\n+// error: ErrorComponent\n+// })\n+\n import {\n warn,\n isObject",
"additions": 7,
... | 2017-04-01T06:07:05 |
huggingface/transformers | e7c5a60368ba817640328a059c2b838f9e00a1dc | 91b5a680c050d56a395e4dd96eb1b48520bf752f | Fixed grammar mistakes (#41799)
* Fixed grammar mistakes
fixed a couple grammar mistakes
* Update README.md
* Change phrasing a bit more
---------
Co-authored-by: Matt <Rocketknight1@users.noreply.github.com> | [
{
"path": "README.md",
"patch": "@@ -64,8 +64,8 @@ limitations under the License.\n <img src=\"https://huggingface.co/datasets/huggingface/documentation-images/resolve/main/transformers/transformers_as_a_model_definition.png\"/>\n </h3>\n \n-Transformers acts as the model-definition framework for state-... | 2025-10-23T12:34:02 |
ollama/ollama | 75295b952899daaa1ad188088c5f37e62a414b55 | db5ef3004c539688f15dbd3fb3ee9d8c0b48fe05 | install: fix enable contrib on debian 12 (#1151)
On debian 12, sources definitions have moved from
/etc/apt/sources.list to /etc/apt/sources.list.d/debian.sources | [
{
"path": "scripts/install.sh",
"patch": "@@ -181,6 +181,9 @@ install_cuda_driver_apt() {\n debian)\n status 'Enabling contrib sources...'\n $SUDO sed 's/main/contrib/' < /etc/apt/sources.list | $SUDO tee /etc/apt/sources.list.d/contrib.list > /dev/null\n+ if [ -f ... | 2023-11-16T20:53:06 |
ggml-org/llama.cpp | 1c1409e13169d0ced4b1b4d39fb5b268b7525091 | 7a0e900e3615fa46c074a7fdf900b47d3c0a1c7e | embedding: add raw option for --embd-output-format (#16541)
* Add --embd-output-format raw for plain numeric embedding output
This new option outputs embeddings as raw space-separated floats, without JSON or 'embedding N:' prefixes. Useful for downstream vector pipelines and scripting.
* Move raw output handling int... | [
{
"path": "common/arg.cpp",
"patch": "@@ -3248,7 +3248,7 @@ common_params_context common_params_parser_init(common_params & params, llama_ex\n ).set_examples({LLAMA_EXAMPLE_EMBEDDING}));\n add_opt(common_arg(\n {\"--embd-output-format\"}, \"FORMAT\",\n- \"empty = default, \\\"array\\\... | 2025-10-28T10:51:41 |
denoland/deno | 131b706bcfadea4d50e6c87bed3fc165b9f02d84 | 23b14d5d5b6ebb26ef21500dafc0adcbb53e3731 | fix(ext/node): emit close on both paired MessagePorts (#32092)
Ref https://nodejs.org/api/worker_threads.html#portclose
Fixes `test-worker-message-channel.js` | [
{
"path": "ext/node/polyfills/worker_threads.ts",
"patch": "@@ -20,6 +20,7 @@ import {\n MessagePortPrototype,\n MessagePortReceiveMessageOnPortSymbol,\n nodeWorkerThreadCloseCb,\n+ nodeWorkerThreadCloseCbInvoked,\n refMessagePort,\n serializeJsMessageData,\n unrefParentPort,\n@@ -67,6 +68,7 @@... | 2026-02-09T14:31:33 |
huggingface/transformers | 91b5a680c050d56a395e4dd96eb1b48520bf752f | d4562bb8aefed5a7d0e5b20e140e3640527f19e8 | [Trainer] remove env vars (#41697)
* remove env var
* style
* fix value
* update
* fix
* style
* fix
* maybe this time
* rm tests
* fix | [
{
"path": "src/transformers/trainer.py",
"patch": "@@ -209,7 +209,6 @@\n \n if is_accelerate_available():\n from accelerate import Accelerator, skip_first_batches\n- from accelerate import __version__ as accelerate_version\n from accelerate.state import AcceleratorState\n from accelerate.util... | 2025-10-23T12:17:20 |
vuejs/vue | 80fa9bf3d69c9b3c3848b927454aca94990edecf | 1648adb6c7bcc8a3a8dd887640858051ce4dc58d | fix hydration tests | [
{
"path": "test/unit/modules/vdom/patch/hydration.spec.js",
"patch": "@@ -1,7 +1,7 @@\n import Vue from 'vue'\n import VNode from 'core/vdom/vnode'\n-import { SSR_ATTR } from 'shared/util'\n import { patch } from 'web/runtime/patch'\n+import { SSR_ATTR } from 'shared/constants'\n \n describe('vdom patch: hy... | 2017-03-31T09:23:49 |
ollama/ollama | d660eebf22c11c5b13bc990aaa4f9bf538bc5480 | cac11c9137294961adbb08a6c279ab652af3bcdc | fix create from model tag | [
{
"path": "cmd/cmd.go",
"patch": "@@ -78,7 +78,7 @@ func CreateHandler(cmd *cobra.Command, args []string) error {\n \n \t\t\tbin, err := os.Open(path)\n \t\t\tif errors.Is(err, os.ErrNotExist) && c.Name == \"model\" {\n-\t\t\t\t// value might be a model reference and not a real file\n+\t\t\t\tcontinue\n \t\... | 2023-11-15T18:57:09 |
ggml-org/llama.cpp | ad8d36beffd791db10c94eb9e964afb891e3ca55 | c053e18a66dd95dc340aa61317877c2a41d4e3cf | sycl: add SSM_CONV operation support (#16800)
* feat: Add SYCL backend support for SSM_CONV operator
* Implement State Space Model Convolution 1D for SYCL backend
* Add optimized GPU kernel with parallel work distribution
* Support various tensor dimensions and batch sizes
* Full integration with existing SYCL infras... | [
{
"path": "ggml/src/ggml-sycl/backend.hpp",
"patch": "@@ -35,6 +35,7 @@\n #include \"roll.hpp\"\n #include \"rope.hpp\"\n #include \"set_rows.hpp\"\n+#include \"ssm_conv.hpp\"\n #include \"softmax.hpp\"\n #include \"tsembd.hpp\"\n #include \"wkv.hpp\"",
"additions": 1,
"deletions": 0,
"language"... | 2025-10-28T01:50:33 |
denoland/deno | 23b14d5d5b6ebb26ef21500dafc0adcbb53e3731 | c0857ab2ae6b1dfedeaf86b92792afc51c751468 | fix(ext/webgpu): GPUQuene writeBuffer size given in elements of TA (#32031)
Fixes https://github.com/denoland/deno/issues/31212 | [
{
"path": "ext/webgpu/queue.rs",
"patch": "@@ -9,6 +9,7 @@ use deno_core::WebIDL;\n use deno_core::cppgc::Ref;\n use deno_core::futures::channel::oneshot;\n use deno_core::op2;\n+use deno_core::v8;\n use deno_error::JsErrorBox;\n \n use crate::Instance;\n@@ -128,19 +129,62 @@ impl GPUQueue {\n \n #[requir... | 2026-02-09T14:06:41 |
vuejs/vue | 1648adb6c7bcc8a3a8dd887640858051ce4dc58d | 69e62f0a74b6a6baab1d66dd0433cdfb410bdae7 | fix import | [
{
"path": "src/core/vdom/patch.js",
"patch": "@@ -14,7 +14,7 @@\n \n import VNode from './vnode'\n import config from '../config'\n-import { SSR_ATTR } from 'shared/util'\n+import { SSR_ATTR } from 'shared/constants'\n import { registerRef } from './modules/ref'\n import { activeInstance } from '../instance... | 2017-03-31T09:05:25 |
huggingface/transformers | d4562bb8aefed5a7d0e5b20e140e3640527f19e8 | e46c2ff32ef2c370b9214befacb0802e7ff97203 | Fix Qwen3Next dtype API usage (#41735)
Replace torch.get_current_dtype() with torch.get_default_dtype() to fix FLA compatibility | [
{
"path": "src/transformers/models/qwen3_next/modeling_qwen3_next.py",
"patch": "@@ -638,7 +638,7 @@ def __init__(self, config: Qwen3NextConfig, layer_idx: int):\n eps=self.layer_norm_epsilon,\n activation=self.activation,\n device=torch.cuda.current_device(),... | 2025-10-23T12:02:02 |
denoland/deno | c0857ab2ae6b1dfedeaf86b92792afc51c751468 | 29e64f0e19397664881c7658978fcbe0788a55c1 | fix(ext/node): read from stdin when spawns node with no args (#32088)
When child_process.spawn(process.execPath, []) is used (equivalent to
running `node` with no args), the CLI arg translator produced `deno run
-A` which fails because no script is specified.
In Node.js, `node` with no args and piped stdin reads and ... | [
{
"path": "ext/node/ops/node_cli_parser.rs",
"patch": "@@ -72,10 +72,12 @@ pub fn op_node_translate_cli_args(\n #[serde] args: Vec<String>,\n script_in_npm_package: bool,\n ) -> Result<TranslatedArgs, CliParserError> {\n- // If no args, return early with run -A\n+ // If no args, return early with run ... | 2026-02-09T12:32:27 |
huggingface/transformers | e46c2ff32ef2c370b9214befacb0802e7ff97203 | 3b6ddbcb8882f2cf1caac0c3544439dae062bcdc | Add a safeguard around a flaky test in gemma2 (#41811)
* Fix _compile flag in flex attn integration
* Revert fix and add precaution around test | [
{
"path": "tests/models/gemma2/test_modeling_gemma2.py",
"patch": "@@ -34,6 +34,7 @@\n require_torch_accelerator,\n require_torch_large_accelerator,\n require_torch_large_gpu,\n+ run_test_using_subprocess,\n slow,\n torch_device,\n )\n@@ -136,6 +137,9 @@ def test_model_9b_pipeline_bf1... | 2025-10-23T10:36:50 |
ggml-org/llama.cpp | e1ab0848037c9f9bfe68b3e1cee9ee375e1018a3 | 5a4ff43e7dd049e35942bc3d12361dab2f155544 | mtmd : fix idefics3 preprocessing (#16806)
* mtmd : fix idefics3 preprocessing
* disable granite test
* fix test for granite | [
{
"path": "tools/mtmd/clip.cpp",
"patch": "@@ -171,7 +171,7 @@ struct clip_hparams {\n int32_t n_head;\n int32_t n_layer;\n // idefics3\n- int32_t preproc_image_size = 0;\n+ int32_t preproc_image_size = 0; // aka max_dimension\n int32_t proj_scale_factor = 0;\n \n float image_mean[... | 2025-10-27T22:12:16 |
denoland/deno | 29e64f0e19397664881c7658978fcbe0788a55c1 | c996d21a962f334e0007eaac96964d2a51f4abf9 | fix(ext/node): unref stdin on pause to allow process exit (#32086)
When process.stdin is a pipe without a _handle (PIPE/TCP type), calling
pause() did not unref the underlying Deno stdin resource. This caused
pending reads to keep the event loop alive, preventing the process from
exiting even after stdin was paused.
... | [
{
"path": "ext/node/polyfills/_process/streams.mjs",
"patch": "@@ -170,6 +170,7 @@ function _guessStdinType(fd) {\n }\n \n const _read = function (size) {\n+ io.stdin?.[io.REF]();\n const p = Buffer.alloc(size || 16 * 1024);\n PromisePrototypeThen(io.stdin?.read(p), (length) => {\n // deno-lint-ign... | 2026-02-09T12:31:57 |
huggingface/transformers | 2c5b888c956eb47ef6d7c38fcbaf586ab760f1b7 | 0eb372ba1957f498d31c3af5bf9e31806087b56a | [`Onnx docs`] Remove some traces (#41791)
fix | [
{
"path": ".github/scripts/codeowners_for_review_action",
"patch": "@@ -22,7 +22,6 @@ tests/generation/ @gante\n /src/transformers/models/auto/ @ArthurZucker\n /src/transformers/utils/ @ArthurZucker @Rocketknight1\n /src/transformers/loss/ @ArthurZucker\n-/src/transformers/onnx/ @michaelbenayoun\n \n # Spec... | 2025-10-23T08:34:25 |
ollama/ollama | cc54a416c66f5ee3cf8fbd1f5755f388acd74c14 | c819d7f68aa97ca9e40b9d5370c47cbc4ee0b0e2 | Resume chunk download on UnexpectedEOF errors
If the chunk download is interrupted, resume from where we left off | [
{
"path": "server/download.go",
"patch": "@@ -161,6 +161,9 @@ func (b *blobDownload) run(ctx context.Context, requestURL *url.URL, opts *Regis\n \t\t\t\t\tlog.Printf(\"%s part %d attempt %d failed: %v, retrying\", b.Digest[7:19], i, try, err)\n \t\t\t\t\tcontinue\n \t\t\t\tdefault:\n+\t\t\t\t\tif try > 0 {\... | 2023-11-08T21:24:11 |
ggml-org/llama.cpp | 10640e31aab0819f31c1e1f2d008b019ee737232 | 80d28f104c0c3e61c11d6af073642b246a9fc19c | ggml : fix interpolate with align-corners and ne=1 (#16700)
* ggml : fix interpolate with align-corners and ne=1
* avoid division by zero if one of the spatial dimensions is 1
* cpu, cuda, opencl returned correct result anyway due to clamp
* vulkan didn't clamp for align-corners so results were broken
* fix clang wa... | [
{
"path": "ggml/src/ggml-cpu/ops.cpp",
"patch": "@@ -7519,8 +7519,8 @@ static void ggml_compute_forward_upscale_f32(\n float pixel_offset = 0.5f;\n if (mode_flags & GGML_SCALE_FLAG_ALIGN_CORNERS) {\n pixel_offset = 0.0f;\n- sf0 = (float)(ne0 - 1) / (src0->ne[0] - 1);\n... | 2025-10-27T20:50:22 |
vuejs/vue | 2451c45d4f1d9ff50ab0abd638a3d8bf37ff55e7 | 2fe42ef0c55eb065e7cf6a5850e2de3f1bcf69eb | fix preload for used chunks | [
{
"path": "src/server/template-renderer/index.js",
"patch": "@@ -23,8 +23,8 @@ export type ParsedTemplate = {\n export default class TemplateRenderer {\n template: ParsedTemplate;\n publicPath: string;\n- preloadLinks: ?string;\n- asyncFiles: ?Array<string>;\n+ preloadFiles: ?Array<string>;\n+ prefe... | 2017-03-27T12:26:07 |
denoland/deno | c996d21a962f334e0007eaac96964d2a51f4abf9 | db748af2053d8f348244042e7a47991da803a98f | fix(test): user input clearing test runner output (#32082)
I noticed that we don't sanitise output in the test runner when printing
it. This allows clearing the output from the test runner itself through
"destructive" ansi codes. Ran into this on the Fresh code base.
Before:
<img width="586" height="235" alt="Screens... | [
{
"path": "cli/tools/test/reporters/pretty.rs",
"patch": "@@ -1,8 +1,11 @@\n // Copyright 2018-2026 the Deno authors. MIT license.\n \n+use std::io::IsTerminal;\n+\n use super::common;\n use super::fmt::to_relative_path_or_remote_url;\n use super::*;\n+use crate::util::console::filter_destructive_ansi;\n \n... | 2026-02-09T11:58:41 |
huggingface/transformers | 0eb372ba1957f498d31c3af5bf9e31806087b56a | 87be5595081364ef99393feeaa60d71db3652679 | [quantization] fix torchao tests after 0.14.0 release (#41777)
* initial commit
* clean int4_weight_only
* make style
---------
Co-authored-by: Marc Sun <57196510+SunMarc@users.noreply.github.com> | [
{
"path": "tests/quantization/torchao_integration/test_torchao.py",
"patch": "@@ -48,6 +48,8 @@\n from torchao.quantization import (\n Float8Tensor,\n Float8WeightOnlyConfig,\n+ Int4WeightOnlyConfig,\n+ Int8DynamicActivationInt8WeightConfig,\n Int8WeightOnlyConfig,\... | 2025-10-23T08:26:44 |
ollama/ollama | 1359d6cf3bbc925432d2b2f060e17a39983d7ba9 | 6e2d0224d9e03f6bf236cd1e1cad7b79812e91ea | Fix sudo variable in install.sh (#1034)
It was forgotten to replace sudo at one place with the variable for sudo. | [
{
"path": "scripts/install.sh",
"patch": "@@ -180,7 +180,7 @@ install_cuda_driver_apt() {\n case $1 in\n debian)\n status 'Enabling contrib sources...'\n- $SUDO sed 's/main/contrib/' < /etc/apt/sources.list | sudo tee /etc/apt/sources.list.d/contrib.list > /dev/null\n+ ... | 2023-11-07T17:59:57 |
ggml-org/llama.cpp | 80d28f104c0c3e61c11d6af073642b246a9fc19c | c55d53acec864f64afa1ba92972203dce1bf88f5 | HIP: fix AMDGPU_TARGETS, update documentation (#16803) | [
{
"path": "docs/build.md",
"patch": "@@ -261,10 +261,12 @@ You can download it from your Linux distro's package manager or from here: [ROCm\n - Using `CMake` for Linux (assuming a gfx1030-compatible AMD GPU):\n ```bash\n HIPCXX=\"$(hipconfig -l)/clang\" HIP_PATH=\"$(hipconfig -R)\" \\\n- cmake -S .... | 2025-10-27T20:39:49 |
vuejs/vue | 2fe42ef0c55eb065e7cf6a5850e2de3f1bcf69eb | fae6b87786a2829152407d6cb04e79011c77bdae | fix option passing | [
{
"path": "package.json",
"patch": "@@ -103,6 +103,7 @@\n \"rollup-plugin-replace\": \"^1.1.0\",\n \"rollup-watch\": \"^3.2.2\",\n \"selenium-server\": \"^2.53.1\",\n+ \"serialize-javascript\": \"^1.3.0\",\n \"typescript\": \"^2.1.6\",\n \"uglify-js\": \"^2.6.2\",\n \"vue-ssr-html... | 2017-03-27T11:58:17 |
denoland/deno | db748af2053d8f348244042e7a47991da803a98f | 6c4ced6b360579e04be45deef958f7ec785d3c6b | fix(ext/node): add `threadName` to worker_threads module (#32072)
## Summary
Adds the `threadName` export and `Worker.threadName` getter to the
worker_threads module for Node.js compatibility.
- `threadName` module export: returns the name of the current thread
(empty string for main thread, worker's name inside a w... | [
{
"path": "ext/node/polyfills/worker_threads.ts",
"patch": "@@ -237,6 +237,7 @@ class NodeWorker extends EventEmitter {\n workerData: options?.workerData,\n environmentData: environmentData,\n env: env_,\n+ name: this.#name,\n isEval: !!options?.eval,\n isWorkerThread: tru... | 2026-02-09T10:48:25 |
huggingface/transformers | 87be5595081364ef99393feeaa60d71db3652679 | 2ca506ca1db3a20ef0d74b989edface7aecdef80 | Fix attention mask in mamba layers (#41790)
* not all mamba models are like LFM
* compile friendly
* adjust slow tests expectation
* naming | [
{
"path": "src/transformers/models/bamba/modeling_bamba.py",
"patch": "@@ -486,20 +486,21 @@ def segment_sum(input_tensor):\n return tensor_segsum\n \n \n-is_fast_path_available = all((selective_state_update, causal_conv1d_fn, causal_conv1d_update))\n-\n-\n def apply_mask_to_padding_states(hidden_states... | 2025-10-22T16:15:38 |
ggml-org/llama.cpp | 945501f5ea4b8ca56b181ecb035e9ee3fb31f432 | 75cbdd3fce38ea12d50cd19e73a069aa5dbbd5fa | llama: fix leaked buffers for mmap + split files (#16765) | [
{
"path": "src/llama-model.cpp",
"patch": "@@ -15,7 +15,6 @@\n \n #include <algorithm>\n #include <cassert>\n-#include <cmath>\n #include <cfloat>\n #include <cstring>\n #include <cmath>\n@@ -438,7 +437,7 @@ struct llama_model::impl {\n llama_mlocks mlock_mmaps;\n \n // contexts where the model tens... | 2025-10-27T08:17:31 |
vuejs/vue | 6fcfdbd83f424eba19933d453420d762c9bad767 | 3209f6f517a4fa44c563cd7cc048fa29be1bc930 | warn and handle missing get in computed (fix #5265) (#5267) | [
{
"path": "src/core/instance/state.js",
"patch": "@@ -147,7 +147,16 @@ function initComputed (vm: Component, computed: Object) {\n \n for (const key in computed) {\n const userDef = computed[key]\n- const getter = typeof userDef === 'function' ? userDef : userDef.get\n+ let getter = typeof userD... | 2017-03-27T02:41:29 |
denoland/deno | 6c4ced6b360579e04be45deef958f7ec785d3c6b | 501c6592c9268291b2d6e5479a2f4498f12807f0 | fix(ext/node): set exitCode/signalCode correctly for killed child processes (#32081)
## Summary
- When a child process was killed by a signal (e.g., SIGTERM from a
timeout), `exitCode` was unconditionally set to the raw OS exit code
(e.g., 143 for SIGTERM) instead of `null`
- In Node.js, `exitCode` and `signalCode` ar... | [
{
"path": "ext/node/polyfills/internal/child_process.ts",
"patch": "@@ -542,12 +542,15 @@ export class ChildProcess extends EventEmitter {\n \n (async () => {\n const status = await this.#process.status;\n- this.exitCode = status.code;\n+ this.signalCode = this.signalCode || stat... | 2026-02-08T22:07:30 |
Subsets and Splits
Assembly Language GitHub Issues
Retrieves a sample of assembly-language related commits with their details, but doesn't provide meaningful analysis or patterns beyond basic filtering.
Swift Compiler Issues Analysis
Retrieves all training data for the Swift programming language repository, providing basic filtering but offering limited analytical insight beyond identifying relevant code examples.